@@ -24,11 +24,11 @@
 #include "reader/odscell.h"
 #include "odsdochandlerinterface.h"
 
-class SaxHandlerContentXml;
+class QXmlStreamReaderContentXml;
 
 class OdsDocReader
 {
-  friend SaxHandlerContentXml;
+  friend QXmlStreamReaderContentXml;
 
   public:
   /**
